Authors
=======

Foremost, this library redistributed code found in ndn-python-repo_ and has made changes to it.
You can find the changes and what this library uses in CHANGES.rst_.

The Names of all authors associated with the changes made / implementation of the repository are below:

  * *Justin C Presley* (justincpresley_)

.. _justincpresley: https://github.com/justincpresley
.. _CHANGES.rst: https://github.com/justincpresley/ndn-python-storage/blob/master/CHANGES.rst
.. _ndn-python-repo: https://github.com/UCLA-IRL/ndn-python-repo